NXSDataWriter Tango Class Commands

NXSDataWriter Class Commands
Name | Input type | Output type | Level | Description
State | DEV_VOID | DEV_STATE | OPERATOR | This command gets the device state (stored in its device_state data member) and returns it to the caller.
Status | DEV_VOID | CONST_DEV_STRING | OPERATOR | This command gets the device status (stored in its device_status data member) and returns it to the caller.
OpenFile | DEV_VOID | DEV_VOID | OPERATOR | Opens the H5 file
OpenEntry | DEV_VOID | DEV_VOID | OPERATOR | Creates the new entry
Record | DEV_STRING | DEV_VOID | OPERATOR | Records data for one scan step
CloseEntry | DEV_VOID | DEV_VOID | OPERATOR | Closes the entry
OpenEntryAsynch | DEV_VOID | DEV_VOID | OPERATOR | Creates the new entry in asynchronous mode
RecordAsynch | DEV_STRING | DEV_VOID | OPERATOR | Records data for one scan step in asynchronous mode
CloseEntryAsynch | DEV_VOID | DEV_VOID | OPERATOR | Closes the entry is asynchronous mode
CloseFile | DEV_VOID | DEV_VOID | OPERATOR | Closes the H5 file